package envoy.client.ui;

import java.awt.AWTException;
import java.awt.Image;
import java.awt.MenuItem;
import java.awt.PopupMenu;
import java.awt.SystemTray;
import java.awt.Toolkit;
import java.awt.TrayIcon;
import java.awt.TrayIcon.MessageType;

import envoy.exception.EnvoyException;
import envoy.schema.Message;

/**
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>StatusTrayIcon.java</strong><br>
 * Created: <strong>3 Dec 2019</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy v0.2-alpha
 */
public class StatusTrayIcon {

	private TrayIcon trayIcon;

	public StatusTrayIcon() throws EnvoyException {
		if (!SystemTray.isSupported()) throw new EnvoyException("The Envoy tray icon is not supported.");

		Image img = Toolkit.getDefaultToolkit().createImage(getClass().getResource("envoy_logo.png"));
		trayIcon = new TrayIcon(img, "Envoy Client");
		trayIcon.setImageAutoSize(true);
		trayIcon.setToolTip("You are notified if you have unread messages.");

		PopupMenu popup = new PopupMenu();

		MenuItem exitMenuItem = new MenuItem("Exit");
		exitMenuItem.addActionListener((evt) -> System.exit(0));
		popup.add(exitMenuItem);

		trayIcon.setPopupMenu(popup);
	}

	/**
	 * Makes this {@link StatusTrayIcon} appear in the system tray.
	 * 
	 * @throws EnvoyException
	 */
	public void show() throws EnvoyException {
		try {
			SystemTray.getSystemTray().add(trayIcon);
		} catch (AWTException e) {
			throw new EnvoyException("Could not attach Envoy tray icon to system tray.", e);
		}
	}

	/**
	 * Notifies the user of a message by displaying a popup.
	 * 
	 * @param message the {@link Message} object to display in the popup
	 */
	public void displayMessageNotification(Message message) {
		// TODO: Add event listener
		trayIcon.displayMessage("New message received", message.getContent().get(0).getText(), MessageType.INFO);
	}
}
